@@ -124,6 +124,7 @@ class NVD3Chart:
     color_list = []  # for pie chart
     tag_script_js = True
     charttooltip_dateformat = None
+    x_axis_format = ''
 
     header_css = ['http://nvd3.org/src/nv.d3.css']
     header_js = ['http://nvd3.org/lib/d3.v2.js', 'http://nvd3.org/nv.d3.js']
@@ -167,12 +168,21 @@ class NVD3Chart:
             x = [str(d) for d in x]
 
         # For scatterChart shape & size fields are added in serie
-        if 'shape' in kwargs:
+        if 'shape' in kwargs or 'size' in kwargs:
             if 'size' in kwargs and kwargs["size"]:
                 csize = kwargs["size"]
             else:
-                csize = random.randint(1, 3)
-            serie = [{"x": x[i], "y": y, "shape": kwargs["shape"], "size": csize} for i, y in enumerate(y)]
+                csize = 1
+            if 'shape' in kwargs and kwargs["shape"]:
+                cshape = kwargs["shape"]
+            else:
+                cshape = "circle"
+            serie =[{
+                "x": x[i],
+                "y": y,
+                "shape": cshape,
+                "size": csize[i] if isinstance(csize, list) else csize
+                } for i, y in enumerate(y)]
         else:
             serie = [{"x": x[i], "y": y} for i, y in enumerate(y)]
 
@@ -400,7 +410,10 @@ class NVD3Chart:
         """
         axis = {}
         if format:
-            axis["tickFormat"] = "d3.format(',%s')" % format
+            if format == 'AM_PM':
+                axis["tickFormat"] = "function(d) { return get_am_pm(parseInt(d)); }\n"
+            else:
+                axis["tickFormat"] = "d3.format(',%s')" % format
 
         if label:
             axis["axisLabel"] = label
